/* 
   - The contents of this file are subject to the Mozilla Public
   - License Version 1.1 (the "License"); you may not use this file
   - except in compliance with the License. You may obtain a copy of
   - the License at http://www.mozilla.org/MPL/
   -
   - Software distributed under the License is distributed on an "AS
   - IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
   - implied. See the License for the specific language governing
   - rights and limitations under the License.
   -
   - The Original Code is this file as it was released on
   - November 20, 2003.
   -
   - The Initial Developer of the Original Code is Henk-Johan van Rantwijk.
   - Portions created by Henk-Johan van Rantwijk are Copyright (C) 2003
   - Henk-Johan van Rantwijk.  All Rights Reserved.
   -
   - Contributor(s):
   -  
   -
   - Alternatively, the contents of this file may be used under the
   - terms of the GNU General Public License Version 2 or later (the
   - "GPL"), in which case the provisions of the GPL are applicable
   - instead of those above.  If you wish to allow use of your
   - version of this file only under the terms of the GPL and not to
   - allow others to use your version of this file under the MPL,
   - indicate your decision by deleting the provisions above and
   - replace them with the notice and other provisions required by
   - the GPL.  If you do not delete the provisions above, a recipient
   - may use your version of this file under either the MPL or the
   - GPL.
   -
*/

var resource, tabbrowser, reloadInterval, helpPages, dataCollection = null;
var elementArray = new Array();
var elementIDs = new Array("label", "custom", "firstpage", "image", "location", "interval", 
                           "selected", "allowPlugins", "allowJavascript", "allowMetaRedirects", 
                           "allowSubframes", "allowImages", "interval-enabled", "allow-all", 
                           "suppress-all");
const MZ_TRUE = "true";
const MZ_FALSE = "false";
////////////////////////////////////////////////////////////////////////////////
function initPropertyWindow()
{
  resource = window.arguments[0];
  tabbrowser = window.arguments[1];
  // Initialize element array, used in activateSettings
  for (i in elementIDs) {
    elementArray[i] = document.getElementById(elementIDs[i]);
  }
  initializeRDFStorageFile();
  // Initialize textboxes, checkboxes and buttons
  dataCollection = getTabDataFromResource(RDF.GetResource(resource));
  if (dataCollection) {
    activateSettings(dataCollection);
    // Initialize the 'Allow All' or 'Suppress All' buttons
    onProperty(null);
  }
}
////////////////////////////////////////////////////////////////////////////////
function activateSettings(aDataCollection)
{
  elementArray[0].value = aDataCollection[0].value; // title
  elementArray[1].checked = (aDataCollection[1].value == MZ_TRUE) ? true : false; // custom
  elementArray[2].value = aDataCollection[2].value; // firstpage
  elementArray[3].value = aDataCollection[3].value; // image
  elementArray[4].value = aDataCollection[4].value; // location
  reloadInterval = aDataCollection[5].value; // interval
  elementArray[6].checked = (aDataCollection[6].value == MZ_TRUE) ? false : true;
  elementArray[12].checked = (reloadInterval > 0) ? true : false;
  tabbrowser.initReloadPopup(elementArray[5].firstChild, null, reloadInterval);
  // Tab Properties
  for (var i = 7; i < elementArray.length-3; i++) {
    elementArray[i].checked = (aDataCollection[i].value == MZ_TRUE) ? true : false;
  }  
}
////////////////////////////////////////////////////////////////////////////////
function getDataCollection()
{
  var aDataCollection = new Array();
  // Data Collection buildup
  aDataCollection[0] = {value:elementArray[0].value}; // title
  aDataCollection[1] = {value:elementArray[1].checked ? MZ_TRUE : MZ_FALSE}; // custom
  // Check for missing scheme in 'firstpage' textbox.
  if (elementArray[2].value.indexOf(":") < 0) // Add default scheme
          elementArray[2].value = "http://" + elementArray[2].value;
  aDataCollection[2] = {value:elementArray[2].value}; // firstpage
  aDataCollection[3] = {value:elementArray[3].value}; // image
  // Check for missing scheme in 'location' textbox.
  if (elementArray[4].value.indexOf(":") < 0) // Add default scheme
          elementArray[4].value = "http://" + elementArray[4].value;
  aDataCollection[4] = {value:elementArray[4].value}; // location
  aDataCollection[5] = {value:reloadInterval}; // Reload interval
  aDataCollection[6] = {value:elementArray[6].checked ? MZ_FALSE : MZ_TRUE};
  // Tab Properties
  for (var i = 7; i < 12; i++) {
    aDataCollection[i] = {value:elementArray[i].checked ? MZ_TRUE : MZ_FALSE};
  }
  return aDataCollection;
}
////////////////////////////////////////////////////////////////////////////////
function onProperty(aElement)
{
  var id = aElement ? aElement.getAttribute("id") : "";
  var properties = 0;
  // Count number of checked property checkboxes
  for (var i = 7; i < 12; i++) {
    if (elementArray[i].checked)
      properties++
  }
  // Called from the 'Allow All' or 'Suppress All' buttons
  if (id == elementIDs[13] || id == elementIDs[14]) {
    properties = (id == elementIDs[13]) ? 5 : 0;
    for (i = 7; i < 12; i++)
      elementArray[i].checked = properties ? true : false;
  }
  // Update button state
  elementArray[13].disabled = (properties == 5) ? true : false;
  elementArray[14].disabled = (properties == 0) ? true : false;
}
////////////////////////////////////////////////////////////////////////////////
function onHelp()
{
  if (!helpPages) {
    var stringBundle = document.getElementById("properties");
    helpPages = stringBundle.getString("helpPages-SessionManager");
    stringBundle = null; // Cleanup
  }
  tabbrowser.loadURI(helpPages);
  window.close();
}
////////////////////////////////////////////////////////////////////////////////
function onAccept()
{
  var modifiedDataCollection = getDataCollection();
  var MZ = "http://multizilla.mozdev.org/rdf#";

  try {
    for (var i = 0; i < 12; i++) {
      var currentValue = RDF.GetLiteral(modifiedDataCollection[i].value);

      if (dataCollection[i].value != modifiedDataCollection[i].value) {
        alert("i: "+elementIDs[i]+" old: "+dataCollection[i].value+" new: "+modifiedDataCollection[i].value);
        var property = RDF.GetResource(MZ+elementIDs[i]);
        var newValue = RDF.GetLiteral(modifiedDataCollection[i].value);
        mzRDFStore.Change(RDF.GetResource(resource), property, currentValue, newValue);
      }
    }
  } catch(ex) { 
    alert(i);
  }
  mzRDFStore.QueryInterface(Components.interfaces.nsIRDFRemoteDataSource).Flush();
  window.close();
}

